@@ -49,8 +49,8 @@ from fobi.tests.constants import (
 try:
     # Django 1.7 check
     from django.apps import AppConfig
-    from django.conf import settings
-    User = settings.AUTH_USER_MODEL
+    from django.contrib.auth import get_user_model
+    User = get_user_model()
 except ImportError:
     # Django 1.6 check
     try:
